@@ -1,4 +1,3 @@
 from .linalg import *  # noqa
 from .normalize_activation import *  # noqa
-from .swish import *  # noqa
-from .basis import *  # noqa
+from .soft_one_hot import *  # noqa
